@@ -127,31 +127,6 @@ gconf_key_key        (const gchar* key)
  *  Random stuff 
  */
 
-gboolean
-gconf_file_exists (const gchar* filename)
-{
-  struct stat s;
-  
-  g_return_val_if_fail (filename != NULL,FALSE);
-  
-  return g_stat (filename, &s) == 0;
-}
-
-gboolean
-gconf_file_test(const gchar* filename, int test)
-{
-  struct stat s;
-  if(g_stat (filename, &s) != 0)
-    return FALSE;
-  if(!(test & GCONF_FILE_ISFILE) && S_ISREG(s.st_mode))
-    return FALSE;
-  if(!(test & GCONF_FILE_ISLINK) && S_ISLNK(s.st_mode))
-    return FALSE;
-  if(!(test & GCONF_FILE_ISDIR) && S_ISDIR(s.st_mode))
-    return FALSE;
-  return TRUE;
-}
-
 GConfValue* 
 gconf_value_from_corba_value(const ConfigValue* value)
 {
@@ -2935,17 +2910,31 @@ gconf_get_lock_dir (void)
 
 #if defined (F_SETFD) && defined (FD_CLOEXEC)
 
+#ifndef HAVE_FDWALK
 static void
 set_cloexec (gint fd)
 {
   fcntl (fd, F_SETFD, FD_CLOEXEC);
+#else
+static int
+set_cloexec (void *data, int fd)
+{
+  int *pipes = (int *)data;
+
+  if (fd != pipes[1] && fd > 2)
+    fcntl (fd, F_SETFD, FD_CLOEXEC);
+
+  return 0;
+#endif
 }
 
+
 static void
 close_fd_func (gpointer data)
 {
   int *pipes = data;
   
+#ifndef HAVE_FDWALK
   gint open_max;
   gint i;
   
@@ -2956,6 +2945,9 @@ close_fd_func (gpointer data)
       if (i != pipes[1])
         set_cloexec (i);
     }
+#else
+  (void) fdwalk(set_cloexec, (void *)pipes);
+#endif
 }
 
 #else
@@ -3068,7 +3060,12 @@ gconf_activate_server (gboolean  start_if_not_found,
       
       g_free (argv[0]);
       g_free (argv[1]);
-  
+
+      /* If the server dies, we don't want to block indefinitely in
+	 the read. */
+      close (p[1]);
+      p[1] = -1;
+
       /* Block until server starts up */
       read (p[0], buf, 1);
 
