@@ -90,6 +90,9 @@ gconf_value_new_from_string(GConfValueType type, const gchar* value_str,
 {
   GConfValue* value;
 
+  g_return_val_if_fail (type != GCONF_VALUE_LIST, NULL);
+  g_return_val_if_fail (type != GCONF_VALUE_PAIR, NULL);
+
   value = gconf_value_new(type);
 
   switch (type)
@@ -1373,6 +1376,8 @@ gconf_meta_info_new(void)
 void
 gconf_meta_info_free(GConfMetaInfo* gcmi)
 {
+  set_string(&gcmi->schema, NULL);
+  set_string(&gcmi->mod_user, NULL);
   g_free(gcmi);
 }
 
