@@ -20,8 +20,11 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-internals.h>
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <math.h>
+#include <locale.h>
 
 static void
 check(gboolean condition, const gchar* fmt, ...)
@@ -145,7 +148,7 @@ check_quoting(void)
 
       check (error == NULL,
              "error parsing quoted string: %s",
-             error ? error->message : NULL);
+             error ? error->message : "<NULL>");
       
       check (strcmp(*testp, unquoted) == 0,
              "Original: `%s'\nUnquoted: `%s'\nNot equal?",
